@@ -4,17 +4,15 @@ use strict;
 use warnings;
 use v5.16;
 use base 'TAP::Formatter::File';
-# use TAP::Parser::YAMLish::Reader;
-
-our $VERSION = '0.3.0_1';
+our $VERSION = '0.3.0_2';
 
 # My file, my terms.
 my $TRIPHASIC_REGEX = qr/
 \s*
-  (?<test_name>
-    Failed\stest                  # Beginning Needle
-    (?:\s*'[^']+')?    # Test Name [usually last param in assertion]
-  )                            # -- Optional
+  (?<test_name>                   # Test header
+    Failed\stest                  
+    (?:\s*'[^']+')?               # Test name [usually last param in an assertion, optional]
+  )
   \s*
   at\s(?<filename>.+)           # Location: File
   \s*
@@ -38,7 +36,7 @@ sub open_test {
   # suffice, but `throws_ok` & `lives_ok` report via `unknown`...
   # But this is real life...
   # so...
-  my $handler =  sub {
+  my $handler = sub {
     my $result = shift;
     $result = $result->raw;
     # Skip all messages that are not comments
@@ -53,8 +51,11 @@ sub open_test {
 
     # Push a new buffer on every failed test
     push(@{$parser->{_tap_comments}}, '') if $result =~ /^Failed test/;
-    # Just in case something is printed before reachign a "Failed test", add a buffer
-    push(@{$parser->{_tap_comments}}, "Failed test\n") unless defined $parser->{_tap_comments}[-1];
+
+    # Just in case something is printed before reaching a "Failed test":
+    #   add a new buffer
+    push(@{$parser->{_tap_comments}}, "Failed test\n")
+      unless defined $parser->{_tap_comments}[-1];
 
     $parser->{_tap_comments}[-1] .= $result . "\n";
   };
@@ -65,7 +66,7 @@ sub open_test {
   # Enable YAML Support
   $parser->version(13);
   $parser->callback(yaml => sub {
-    push @{$parser->{_tap_yaml}}, $_[0]->data;
+      push @{$parser->{_tap_yaml}}, $_[0]->data;
   });
 
   return $session;
@@ -123,14 +124,15 @@ sub _process_captured_tap_comments {
 # this needs a re-design the moment I understand better all parts involved...
 sub summary {
   my ($self, $aggregate, $interrupted) = @_;
-  # $self->SUPER::summary($aggregate, $interrupted);
-  $self->_output("\n= GitHub Actions Report =\n");
+  $self->SUPER::summary($aggregate, $interrupted);
 
   my $total = $aggregate->total;
   my $passed = $aggregate->passed;
 
   return if ($total == $passed && !$aggregate->has_problems);
 
+  $self->_output("\n= GitHub Actions Report =\n");
+
   for my $test ($aggregate->descriptions) {
     my ($parser) = $aggregate->parsers($test);
 
@@ -197,11 +199,26 @@ the comments to produce GitHub-Actions-compatible output.
 C<TAP::Formatter::GitHubActions> provides GitHub-Actions-compatible output for
 I<prove>.
 
+It parses TAP output and tries it's best to guess where errors are located.
+For more accurate results, use in cojunction with
+L<Test2::Formatter::YAMLEnhancedTAP>.
+
+L<Test2::Formatter::YAMLEnhancedTAP> enriches the TAP output generated by
+L<Test2> and friends (L<Test::More>, L<Test::Most>) with an additional context
+in YAML format (compliant with TAP version 13) that includes the precise
+location of the failure.
+
 =head1 SEE ALSO
 
-- JUnit Formatter: L<TAP::Formatter::JUnit>
+=over 1
 
-- L<GitHub Workflow Commands Documentation|https://docs.github.com/en/actions/using-workflows/workflow-commands-for-github-actions#setting-an-error-message>
+- L<TAP::Formatter::JUnit>: JUnit XML output for your Tests!
+
+- L<Test2::Formatter::YAMLEnhancedTAP>: Enhanced TAP Output for your tests!
+
+- L<GitHub Workflow Commands Documentation|https://docs.github.com/en/actions/using-workflows/workflow-commands-for-github-actions#setting-an-error-message>: For more information about the output syntax
+
+=back
 
 =head1 AUTHOR
 
